@@ -1,16 +1,17 @@
+from zoo_framework.handler.event_reactor import EventReactor
 from .params_factory import ParamsFactory
-from .param_path import ParamPath
+from .params_path import ParamsPath
+
+cage_list = []
 
 
-def singleton(cls):
-    _instance = {}
-
-    def _singleton():
-        if cls not in _instance:
-            _instance[cls] = cls()
-        return _instance[cls]
-
-    return _singleton
+def cage(cls):
+    def _cage():
+        if cls not in cage_list:
+            cage_list[cls] = cls()
+        return cage_list[cls]
+    
+    return _cage
 
 
 worker_threads = []
@@ -20,18 +21,18 @@ def worker():
     def inner(cls):
         worker_threads.append(cls())
         return cls
-
+    
     return inner
 
 
-websocket_events = {}
+event_map = {}
 
 
 def event(topic: str):
     def inner(func):
-        websocket_events[topic] = func
+        event_map[topic] = func
         return func
-
+    
     return inner
 
 
@@ -44,16 +45,16 @@ def params(cls):
             return config_params[cls.__name__]
         params_list = dir(cls)
         for param in params_list:
-            param_path = getattr(cls, param)
-            if not isinstance(param_path, ParamPath):
+            params_path = getattr(cls, param)
+            if not isinstance(params_path, ParamsPath):
                 continue
-            param_value = param_path.get_value()
-            default_value = param_path.get_default()
+            param_value = params_path.get_value()
+            default_value = params_path.get_default()
             value = ParamsFactory().get_params(param_value, default_value=default_value)
             setattr(cls, param, value)
         config_params[cls.__name__] = cls
         return cls
-
+    
     return inner()
 
 
@@ -64,5 +65,5 @@ def configure(topic: str):
     def inner(func):
         config_funcs[topic] = func
         return func
-
+    
     return inner
